from charmhelpers.core.hookenv import (
    action_get,
    action_fail,
    action_set,
    config,
    status_set,
)

from charms.reactive import (
    remove_state as remove_flag,
    set_state as set_flag,
    when,
    when_not,
)
import charms.sshproxy

@when_not('bgpfrr.installed')
def install_bgpfrr():
    # Do your setup here.
    #
    # If your charm has other dependencies before it can install,
    # add those as @when() clauses above., or as additional @when()
    # decorated handlers below
    #
    # See the following for information about reactive charms:
    #
    #  * https://jujucharms.com/docs/devel/developer-getting-started
    #  * https://github.com/juju-solutions/layer-basic#overview
    #
    set_flag('bgpfrr.installed')

@when('actions.bgp-init')
def bgp_init():
    err = ''
    routerbgp = "\'router bgp " + action_get("as") + "\'"
    try:
        cmd = "grep -q -F 'router bgp' /var/snap/frr/72/bgpd.conf || sudo echo " + routerbgp + " >> /var/snap/frr/72/bgpd.conf | sponge /var/snap/frr/72/bgpd.conf"
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        charms.sshproxy._run("sudo snap restart --reload frr")
        remove_flag('actions.bgp-init')

@when('actions.bgp-neighbor')
def bgp_neighbor():
    err = ''
    neighborbgp = "\'neighbor " + action_get("remote-ip")
    neighborbgp_as = neighborbgp + " remote-as " + action_get("remote-as") + "\'"
    try:
        cmd = "grep -q -F " + neighborbgp + "\' /var/snap/frr/72/bgpd.conf || sudo echo " + neighborbgp_as + " >> /var/snap/frr/72/bgpd.conf"
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        charms.sshproxy._run("sudo snap restart --reload frr")
        remove_flag('actions.bgp-neighbor')

@when('actions.bgp-neighbor-delete')
def bgp_neighbor_delete():
    err = ''
    neighborbgp = "\'/" + action_get("remote-ip") + "/d\'"
    try:
        cmd = "sed -i " + neighborbgp + " /var/snap/frr/72/bgpd.conf"
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        charms.sshproxy._run("sudo snap restart --reload frr")        
        remove_flag('actions.bgp-neighbor-delete')

@when('actions.bgp-network')
def bgp_neighbor():
    err = ''
    networkbgp = "\'network " + action_get("network") + "\'"
    try:
        cmd = "sudo echo " + networkbgp + " >> /var/snap/frr/72/bgpd.conf"
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        charms.sshproxy._run("sudo snap restart --reload frr")        
        remove_flag('actions.bgp-network')  

@when('actions.restart')
def restart():
    err = ''
    try:
        # Enter the command to restart your service(s)
        cmd = "sudo snap restart --reload frr"
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        remove_flag('actions.restart')
